==> western-world-3.0.439.tgz: package/src/defs/grass.js <==
export const grass = `
<symbol id="grass_1" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M760.6,7612.1c0-244.7,189-328.1,420.1-185.2c231,142.8,420.1,343,420.1,444.9c0,101.9-189,185.2-420.1,185.2 C949.6,8057,760.6,7856.8,760.6,7612.1z"/>
	<path class="grass" d="M3064.4,6766.8C2665,4948,3007.8,4869.6,3829.1,6592c575.2,1206.3,594.4,1465,108.7,1465 C3613.3,8057,3220.3,7476.4,3064.4,6766.8L3064.4,6766.8z"/>
	<path class="grass" d="M6209,7240.3c494.1-923.3,1224.5-1471.9,1539.8-1156.6c343,343-841,1973.3-1433.1,1973.3 C5907.3,8057,5880.7,7853.7,6209,7240.3L6209,7240.3z"/>
</symbol>

<symbol id="grass_2" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M2043.7,7358.1c-289.5-319.9-526.4-682.7-526.4-806.3c0-384.5,1187.1,389.3,1383.8,902 C3156.1,8118.1,2683.9,8065.4,2043.7,7358.1L2043.7,7358.1z"/>
    <path class="grass" d="M3233.4,7383.1c-94.7-306.1-376.5-1026.6-626.1-1601c-584.3-1344.7-571.7-1516.5,72.5-982.3 c522.4,433.2,1382,2182.1,1382,2811.7C4061.8,8157.1,3418.1,7979.6,3233.4,7383.1L3233.4,7383.1z"/>
    <path class="grass" d="M4372.2,6747c-4.2-656-139.4-1761.2-300.5-2455.9C3910.7,3596.3,3840,2966.7,3914.7,2892 c271-271,1406.4,2691.1,1447.2,3775.5c41.2,1097.1,45.8,1093,315.5-279.8C5976.2,4866.4,6740.1,3487,7283.7,3487 c189.6,0,264.8,178.9,167.2,397.6c-97.7,218.7-506.6,1218.1-908.7,2221c-584.5,1457.7-874.6,1824.4-1446.7,1828.7 C4480.9,7938.8,4378.8,7771.1,4372.2,6747L4372.2,6747z"/>
    <path class="grass" d="M6447.1,7621.6c108.1-174.9,259.7-318,336.8-318c77.1,0,140.3,143.1,140.3,318s-151.6,318-336.8,318 C6402.1,7939.7,6339,7796.6,6447.1,7621.6L6447.1,7621.6z"/>
</symbol>

<symbol id="grass_3" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
	<path class="grass" d="M1033,6707.7C790.5,6012,664.2,5442.8,752.3,5442.8s565.5,569.2,1060.8,1264.9 c701.8,985.6,763.8,1264.9,280.8,1264.9C1752.9,7972.6,1275.5,7403.4,1033,6707.7L1033,6707.7z"/>
	<path class="grass" d="M3499.7,7182c0-434.8-96.9-1430.9-215.4-2213.5l-215.4-1423L3905.6,5232 C4914.5,7265.5,4973,7972.5,4132.1,7972.5C3784.3,7972.5,3499.6,7616.8,3499.7,7182L3499.7,7182z"/>
	<path class="grass" d="M5840.1,7023.9c330.1-1083.3,1408.7-2424.2,1949.8-2424.2c200.7,0-22.4,758.9-495.5,1686.5 C6368,8101.8,5355,8615.9,5840,7024L5840.1,7023.9z"/>
</symbol>

<symbol id="grass_4" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M864.2,6354.1c-894.4-2140.7-519.5-2410.5,671.5-483.3C2605.9,7602.4,2690.3,7974.1,2013,7974.1 C1753.5,7974.1,1236.5,7245.1,864.2,6354.1L864.2,6354.1z"/>
    <path class="grass" d="M3058.8,5392.3c-260.9-1420-399.3-2662.5-307.6-2761.1c255.5-274.4,1957.8,3665.5,1968.9,4557 c5.6,432.2-259.4,785.8-588.6,785.8C3757.4,7974.1,3355.4,7006.6,3058.8,5392.3L3058.8,5392.3z"/>
    <path class="grass" d="M5430.2,6963.9c585.9-1899.3,1567.6-3479.8,2161.3-3479.8c422.7,0,273.9,645.5-517.8,2245.1 C5949.3,8001.2,4857,8821.7,5430.2,6963.9L5430.2,6963.9z"/>
</symbol>

<symbol id="grass_6" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M4606.3,273.4c-55.6,23.2-162,192.3-329.8,472.4c-260.1,434-638.9,1357.3-841.6,2051.6l-368.2,1262.7 l-296.5-1104.8C2474.2,1852.2,1704.8,745.7,1233.5,745.7c-224.7,0,853.8,2752.4,1650.9,4212.9c175,320.7,248.7,652.6,163.9,737.3 c-84.8,84.7-312.6-142-506.4-504.1c-598.8-1118.9-998-725.6-492.1,485.1c427.9,1024.1,427.6,1101.6-3.3,744 c-760.8-631.4-897.4-129.7-259.9,954.5c448.3,762.4,608.8,866.3,694,449.5c90.5-442.6,162.2-461.4,389.8-102 c194,306.3,287.5,104.1,307.5-664.3l29-1104.8l370.5,1003.2c597.5,1617.8,686,1454.4,686-1266.1c0-1418,109.4-3288,242.9-4155.9 C4649.9,601.3,4698.9,234.6,4606.3,273.4L4606.3,273.4z"/>
    <path class="grass" d="M6362.8,1409.1c-137.6-12.6-477.8,379.3-911.6,1151.8c-521.7,929.1-668.3,1746.4-681.3,3801.1 c-10.3,1622.7-45.2,1673,145.5,1555.2c169.1-104.5,452.9,257.7,452.9-261.5c0-986.3,680.5-2573.3,1507.6-3516.6 c699.1-797.3,91.7-680.1-816.3,157.6l-769.6,710.3l234.9-789.3c129.1-434,423.6-1250.6,654.3-1814.8 C6447.8,1746.1,6484.2,1420.2,6362.8,1409.1L6362.8,1409.1z"/>
</symbol>

<symbol id="grass_7" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M1055.3,7047.3c-743.7-1135.9-647.4-1437.9,175.5-550l583,629.1l-197-686.9 c-108.3-377.8-312.8-903.2-454.3-1167.6c-422.8-790-281.3-1134.3,210.1-511.2c570.7,723.6,994.1,2194.5,804,2793.3 C1967.2,8213.8,1756.8,8118.7,1055.3,7047.3L1055.3,7047.3z"/>
	<path class="grass" d="M2526.8,6673.2c-0.8-733.1-112.6-1734-248.7-2224.1c-136.1-490.1-189.5-949-118.7-1019.8 c220.4-220.4,1052.5,1868.2,1084.5,2722.3c30.1,799.6,33.4,796.7,230-203.9c212.4-1081.4,772.3-2114.4,1146-2114.4 c286.9,0,283.9,83.9-27.2,766.8c-204.9,449.8-160.4,739.7,231.8,1508.6c267,523.4,485.5,1163.8,485.5,1422.9 c0,402.7-137.4,465.8-944.2,434.2c-792.8-31.1-926.4-105.2-833.1-462c61.1-233.7,16.6-425-99-425c-115.6,0-210.1,208.6-210.1,463.7 c0,257.6-154.6,463.7-347.7,463.7C2607.2,8006.1,2527.8,7702.9,2526.8,6673.2L2526.8,6673.2z M4583.9,6826.7 c-319.8-956.2-664.9-1390.9-664.9-837.4c0,637.4,36,744.6,231.8,691.6c102-27.6,253.1,219.4,335.8,549 c82.7,329.5,197.9,551.6,256.1,493.5C4800.8,7665.2,4729.4,7261.7,4583.9,6826.7L4583.9,6826.7z"/>
	<path class="grass" d="M5644.8,6881.8c-82.6-592.9-232.8-1469.3-333.8-1947.3c-101-478.1-104.5-869.3-7.9-869.3 c220.1,0,929.5,1828.5,947.5,2442c7.6,259.3,251.8-68.8,566.4-761.2c304.2-669.4,699.5-1217.1,878.5-1217.1 c251.1,0,205.2,251.4-201.1,1101.2c-289.6,605.6-601.6,1361.1-693.5,1678.9c-149.3,516.6-126.7,544.3,214.2,261.4 c325.3-270,381.2-264.6,381.2,36.6c0,247.9-238.3,352.9-800.7,352.9C5819,7959.8,5790.5,7927.5,5644.8,6881.8L5644.8,6881.8z"/>
</symbol>

<symbol id="grass_8" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color)}</style>
    <path class="grass" d="M1260.2,7243.2C1138.5,6820.1,884,6095.4,694.6,5632.6c-541.2-1322.4,573.1-428.7,1358,1089 c560.5,1087.6,565.9,1290.8,49.5,1290.8c-340.7,0-718.9-346.2-840.6-769.3L1260.2,7243.2z"/>
    <path class="grass" d="M3197.8,5521.6c-586.8-2922-335-3547.8,563-1398.5c1120.9,2685.9,1302.2,3889.4,582.4,3889.4 c-433.8,0-810.8-818.9-1146.6-2490.8L3197.8,5521.6z"/>
    <path class="grass" d="M5533,6803.7C5901,5307,6965,3616.8,7539.1,3616.8c593.1,0,560.3,146.6-537.3,2405.8 C5930.8,8227,5070.6,8684.5,5533,6803.7L5533,6803.7z"/>
</symbol>


`;

==> western-world-3.0.629.tgz: package/src/defs/grass.js <==
export const grass = `
<symbol id="grass_1" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M760.6,7612.1c0-244.7,189-328.1,420.1-185.2c231,142.8,420.1,343,420.1,444.9c0,101.9-189,185.2-420.1,185.2 C949.6,8057,760.6,7856.8,760.6,7612.1z"/>
	<path class="grass" d="M3064.4,6766.8C2665,4948,3007.8,4869.6,3829.1,6592c575.2,1206.3,594.4,1465,108.7,1465 C3613.3,8057,3220.3,7476.4,3064.4,6766.8L3064.4,6766.8z"/>
	<path class="grass" d="M6209,7240.3c494.1-923.3,1224.5-1471.9,1539.8-1156.6c343,343-841,1973.3-1433.1,1973.3 C5907.3,8057,5880.7,7853.7,6209,7240.3L6209,7240.3z"/>
</symbol>

<symbol id="grass_2" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M2043.7,7358.1c-289.5-319.9-526.4-682.7-526.4-806.3c0-384.5,1187.1,389.3,1383.8,902 C3156.1,8118.1,2683.9,8065.4,2043.7,7358.1L2043.7,7358.1z"/>
    <path class="grass" d="M3233.4,7383.1c-94.7-306.1-376.5-1026.6-626.1-1601c-584.3-1344.7-571.7-1516.5,72.5-982.3 c522.4,433.2,1382,2182.1,1382,2811.7C4061.8,8157.1,3418.1,7979.6,3233.4,7383.1L3233.4,7383.1z"/>
    <path class="grass" d="M4372.2,6747c-4.2-656-139.4-1761.2-300.5-2455.9C3910.7,3596.3,3840,2966.7,3914.7,2892 c271-271,1406.4,2691.1,1447.2,3775.5c41.2,1097.1,45.8,1093,315.5-279.8C5976.2,4866.4,6740.1,3487,7283.7,3487 c189.6,0,264.8,178.9,167.2,397.6c-97.7,218.7-506.6,1218.1-908.7,2221c-584.5,1457.7-874.6,1824.4-1446.7,1828.7 C4480.9,7938.8,4378.8,7771.1,4372.2,6747L4372.2,6747z"/>
    <path class="grass" d="M6447.1,7621.6c108.1-174.9,259.7-318,336.8-318c77.1,0,140.3,143.1,140.3,318s-151.6,318-336.8,318 C6402.1,7939.7,6339,7796.6,6447.1,7621.6L6447.1,7621.6z"/>
</symbol>

<symbol id="grass_3" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
	<path class="grass" d="M1033,6707.7C790.5,6012,664.2,5442.8,752.3,5442.8s565.5,569.2,1060.8,1264.9 c701.8,985.6,763.8,1264.9,280.8,1264.9C1752.9,7972.6,1275.5,7403.4,1033,6707.7L1033,6707.7z"/>
	<path class="grass" d="M3499.7,7182c0-434.8-96.9-1430.9-215.4-2213.5l-215.4-1423L3905.6,5232 C4914.5,7265.5,4973,7972.5,4132.1,7972.5C3784.3,7972.5,3499.6,7616.8,3499.7,7182L3499.7,7182z"/>
	<path class="grass" d="M5840.1,7023.9c330.1-1083.3,1408.7-2424.2,1949.8-2424.2c200.7,0-22.4,758.9-495.5,1686.5 C6368,8101.8,5355,8615.9,5840,7024L5840.1,7023.9z"/>
</symbol>

<symbol id="grass_4" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M864.2,6354.1c-894.4-2140.7-519.5-2410.5,671.5-483.3C2605.9,7602.4,2690.3,7974.1,2013,7974.1 C1753.5,7974.1,1236.5,7245.1,864.2,6354.1L864.2,6354.1z"/>
    <path class="grass" d="M3058.8,5392.3c-260.9-1420-399.3-2662.5-307.6-2761.1c255.5-274.4,1957.8,3665.5,1968.9,4557 c5.6,432.2-259.4,785.8-588.6,785.8C3757.4,7974.1,3355.4,7006.6,3058.8,5392.3L3058.8,5392.3z"/>
    <path class="grass" d="M5430.2,6963.9c585.9-1899.3,1567.6-3479.8,2161.3-3479.8c422.7,0,273.9,645.5-517.8,2245.1 C5949.3,8001.2,4857,8821.7,5430.2,6963.9L5430.2,6963.9z"/>
</symbol>

<symbol id="grass_6" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M4606.3,273.4c-55.6,23.2-162,192.3-329.8,472.4c-260.1,434-638.9,1357.3-841.6,2051.6l-368.2,1262.7 l-296.5-1104.8C2474.2,1852.2,1704.8,745.7,1233.5,745.7c-224.7,0,853.8,2752.4,1650.9,4212.9c175,320.7,248.7,652.6,163.9,737.3 c-84.8,84.7-312.6-142-506.4-504.1c-598.8-1118.9-998-725.6-492.1,485.1c427.9,1024.1,427.6,1101.6-3.3,744 c-760.8-631.4-897.4-129.7-259.9,954.5c448.3,762.4,608.8,866.3,694,449.5c90.5-442.6,162.2-461.4,389.8-102 c194,306.3,287.5,104.1,307.5-664.3l29-1104.8l370.5,1003.2c597.5,1617.8,686,1454.4,686-1266.1c0-1418,109.4-3288,242.9-4155.9 C4649.9,601.3,4698.9,234.6,4606.3,273.4L4606.3,273.4z"/>
    <path class="grass" d="M6362.8,1409.1c-137.6-12.6-477.8,379.3-911.6,1151.8c-521.7,929.1-668.3,1746.4-681.3,3801.1 c-10.3,1622.7-45.2,1673,145.5,1555.2c169.1-104.5,452.9,257.7,452.9-261.5c0-986.3,680.5-2573.3,1507.6-3516.6 c699.1-797.3,91.7-680.1-816.3,157.6l-769.6,710.3l234.9-789.3c129.1-434,423.6-1250.6,654.3-1814.8 C6447.8,1746.1,6484.2,1420.2,6362.8,1409.1L6362.8,1409.1z"/>
</symbol>

<symbol id="grass_7" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M1055.3,7047.3c-743.7-1135.9-647.4-1437.9,175.5-550l583,629.1l-197-686.9 c-108.3-377.8-312.8-903.2-454.3-1167.6c-422.8-790-281.3-1134.3,210.1-511.2c570.7,723.6,994.1,2194.5,804,2793.3 C1967.2,8213.8,1756.8,8118.7,1055.3,7047.3L1055.3,7047.3z"/>
	<path class="grass" d="M2526.8,6673.2c-0.8-733.1-112.6-1734-248.7-2224.1c-136.1-490.1-189.5-949-118.7-1019.8 c220.4-220.4,1052.5,1868.2,1084.5,2722.3c30.1,799.6,33.4,796.7,230-203.9c212.4-1081.4,772.3-2114.4,1146-2114.4 c286.9,0,283.9,83.9-27.2,766.8c-204.9,449.8-160.4,739.7,231.8,1508.6c267,523.4,485.5,1163.8,485.5,1422.9 c0,402.7-137.4,465.8-944.2,434.2c-792.8-31.1-926.4-105.2-833.1-462c61.1-233.7,16.6-425-99-425c-115.6,0-210.1,208.6-210.1,463.7 c0,257.6-154.6,463.7-347.7,463.7C2607.2,8006.1,2527.8,7702.9,2526.8,6673.2L2526.8,6673.2z M4583.9,6826.7 c-319.8-956.2-664.9-1390.9-664.9-837.4c0,637.4,36,744.6,231.8,691.6c102-27.6,253.1,219.4,335.8,549 c82.7,329.5,197.9,551.6,256.1,493.5C4800.8,7665.2,4729.4,7261.7,4583.9,6826.7L4583.9,6826.7z"/>
	<path class="grass" d="M5644.8,6881.8c-82.6-592.9-232.8-1469.3-333.8-1947.3c-101-478.1-104.5-869.3-7.9-869.3 c220.1,0,929.5,1828.5,947.5,2442c7.6,259.3,251.8-68.8,566.4-761.2c304.2-669.4,699.5-1217.1,878.5-1217.1 c251.1,0,205.2,251.4-201.1,1101.2c-289.6,605.6-601.6,1361.1-693.5,1678.9c-149.3,516.6-126.7,544.3,214.2,261.4 c325.3-270,381.2-264.6,381.2,36.6c0,247.9-238.3,352.9-800.7,352.9C5819,7959.8,5790.5,7927.5,5644.8,6881.8L5644.8,6881.8z"/>
</symbol>

<symbol id="grass_8" viewBox="0 0 8192 8192">
    <style>.grass{fill:var(--color, green)}</style>
    <path class="grass" d="M1260.2,7243.2C1138.5,6820.1,884,6095.4,694.6,5632.6c-541.2-1322.4,573.1-428.7,1358,1089 c560.5,1087.6,565.9,1290.8,49.5,1290.8c-340.7,0-718.9-346.2-840.6-769.3L1260.2,7243.2z"/>
    <path class="grass" d="M3197.8,5521.6c-586.8-2922-335-3547.8,563-1398.5c1120.9,2685.9,1302.2,3889.4,582.4,3889.4 c-433.8,0-810.8-818.9-1146.6-2490.8L3197.8,5521.6z"/>
    <path class="grass" d="M5533,6803.7C5901,5307,6965,3616.8,7539.1,3616.8c593.1,0,560.3,146.6-537.3,2405.8 C5930.8,8227,5070.6,8684.5,5533,6803.7L5533,6803.7z"/>
</symbol>


`;
